Skip to contentSkip to conversation

iotests: 163 is not quick

PATCH Applied Eric Blake 2 participants 2 messages Mar 10, 2018 – Mar 19, 2018

lore
Share & tools
lore

Eric Blake

author
#0 lore raw

PATCH 1/1 iotests: 163 is not quick

Testing on ext4, most 'quick' qcow2 tests took less than 5 seconds, but 163 took more than 20. Let's remove it from the quick set.

---
 tests/qemu-iotests/group | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
tests/qemu-iotests/group +1 -1
index a2dfe79d862..657055bae1a 100644
@@ -167,7 +167,7 @@
 159 rw auto quick
 160 rw auto quick
 162 auto quick
-163 rw auto quick
+163 rw auto
 165 rw auto quick
 170 rw auto quick
 171 rw auto quick
Signature · 1 line
2.14.3
Applied
#1 lore raw

Am 10.03.2018 um 22:45 hat Eric Blake geschrieben:

Quoted 4 lines

Testing on ext4, most 'quick' qcow2 tests took less than 5 seconds, but 163 took more than 20. Let's remove it from the quick set.

Takes only 11 seconds for me, but that's still longer than most other tests.

Thanks, applied to the block branch.

Kevin